@@ -32,13 +32,14 @@
 #' 
 #' @export
 match_restrictions <- function(dat, restrictions
-      , adjust
+      , adjust=NULL
       , weight=rep(1,ncol(dat))
       , remove_tag=TRUE
       , ...){
   stopifnot(inherits(dat,"data.frame"))
   stopifnot(inherits(restrictions,"validator"))
-  if (missing(adjust)){
+
+  if (is.null(adjust)){
     adjust <- tagged_values(dat)
     if (is.null(adjust))
       adjust <- array(TRUE, dim=dim(dat))
@@ -91,7 +92,9 @@ Strict inequalities: %s",nm)
     adj <- adjust[i,]
     if (!any(adj)) next
     
-    x <- M[,i]
+    x <- M[,i,drop=TRUE]
+    names(x) <- rownames(M)
+
     constr <- lintools::subst_value(L$A, L$b, variables=!adj, values=x[!adj])
     
     constr <- lintools::compact(
@@ -113,7 +116,9 @@ Strict inequalities: %s",nm)
     }
     M[names(constr$x),i] <- out$x
   }
-  dat[in_res] <- t(M)
+  # as.numeric, to avoid edge case where M is 1x1 and a matrix is stored
+  # in a column (when dat has 1 row).
+  dat[in_res] <- as.numeric(t(M)) 
   if (remove_tag) remove_tag(dat) else dat
 }
 
